Extensible : Remote Calendar

# Remote Calendar Example

This sample uses a simple MVC-style PHP + REST implementation to demonstrate the ease with which you can hook a CalendarPanel up to a back end. In fact, the only changes are in the store (giving it a remote proxy and defining the REST API). The PHP code uses the session object for storage, allowing you to refresh the page without losing data. You can also use Firebug (or any other tool that allows you to inspect XHR requests) to examine each request and verify that the proper HTTP verbs are being used when calling the RESTful API.

The calendar will automatically handle server errors, either via remote validation or non-200 HTTP response codes. If an editor is visible it will remain visible, and if an event was changed directly via a context menu or drag-and-drop the change will not be applied.

View the source

Simulate server errors